<?php

require_once __DIR__ . '/MnetDbManager.php';
require_once __DIR__ . '/MnetAdminPageManager.php';
require_once __DIR__ . '/admin/MnetAuthManager.php';
require_once __DIR__ . '/admin/MnetPluginUtils.php';
require_once __DIR__ . '/admin/MnetSessionManager.php';
require_once __DIR__ . '/admin/MnetAdHandleAjaxCalls.php';
require_once __DIR__ . '/admin/MnetFaqs.php';
require_once __DIR__ . '/admin/MnetAdTag.php';
require_once __DIR__ . '/public/MnetAdPublicHooks.php';
require_once __DIR__ . '/admin/MnetReportManager.php';
require_once __DIR__ . '/admin/MnetAdAdvanceConfiguration.php';
require_once __DIR__ . '/admin/MnetAdBasicConfiguration.php';
require_once __DIR__ . '/admin/MnetAdstxtManager.php';
require_once __DIR__ . '/admin/MnetLogManager.php';
require_once __DIR__ . '/utils/MnetURLs.php';
require_once __DIR__ . '/utils/constants.php';
require_once __DIR__ . '/utils/Response.php';

class MnetAdManagerPlugin
{
    public static function activate()
    {
        MnetDbManager::createTablesOnActivate();
    }

    public static function deactivate()
    {
        MnetLogManager::logEvent('Deactivate');
        MnetAuthManager::clearUserOptions();
    }

    public static function uninstall()
    {
        MnetLogManager::logEvent('Uninstall');
        MnetAuthManager::clearUserOptions();
        MnetDbManager::clearDatabase();
        delete_option('MNET_PLUGIN_VERSION');
    }

    public static function onPluginUpgrade($upgrader_object, $options)
    {
        $mnetPlugin = plugin_basename(__FILE__);
        if ($options['action'] == 'update' && $options['type'] == 'plugin' && isset($options['plugins'])) {
            foreach ($options['plugins'] as $plugin) {
                if ($plugin == $mnetPlugin) {
                    // MnetDbManager::createUpdateDatabase();
                    static::resetOpcache();
                }
            }
        }
    }

    public static function resetOpcache()
    {
        if (!function_exists('opcache_reset')) {
            return;
        }
        try {
            opcache_reset();
        } catch (\Exception $e) { }
    }

    public static function update()
    {
        $current_plugin_version = get_option('MNET_PLUGIN_VERSION');
        if (is_admin() && MNET_PLUGIN_VERSION != $current_plugin_version) {
            MnetDbManager::createUpdateDatabase();
            MnetPluginUtils::setWpOption('MNET_PLUGIN_VERSION', MNET_PLUGIN_VERSION);
            MnetLogManager::logWPDetails();
            $accessToken = MnetAuthManager::getAccessToken();
            if ($accessToken) {
                MnetAdTag::fetchAdTags($accessToken, false);
            }
        }
    }

    public static function run()
    {
        // Verify plugin configuration
        add_action('wp_ajax_mnet_database_check', array('MnetPluginUtils', 'checkDatabaseConfiguration'));

        // Admin page setup
        // add_action('init', array('MnetSessionManager', 'start'));
        add_action('admin_menu', array('MnetAdminPageManager', 'createAdminPage'));
        add_action('admin_head', array('MnetAdminPageManager', 'injectAdminGlobalStyles'));
        add_action('admin_enqueue_scripts', array('MnetAdminPageManager', 'enqueueScripts'));
        add_action('admin_enqueue_scripts', array('MnetAdminPageManager', 'enqueueScriptsLate'), 99999);

        // Admin Ajax call handlers
        add_action('wp_ajax_mnet_admin_ui_error', array('MnetAdHandleAjaxCalls', 'logAdminPageError'));
        // Notices
        add_action('wp_ajax_mnet_get_notices', array('MnetAdHandleAjaxCalls', 'getAllNotices'));
        add_action('wp_ajax_mnet_dismiss_notice', array('MnetAdHandleAjaxCalls', 'dismissNotice'));

        // User Handlers
        add_action('wp_ajax_mnet_auth_user', array('MnetAuthManager', 'authenticateUser'));
        add_action('wp_ajax_mnet_get_customer_name', array('MnetAdHandleAjaxCalls', 'getCustomerName'));
        add_action('wp_ajax_mnet_logout', array('MnetAdHandleAjaxCalls', 'logout'));
        add_action('wp_ajax_mnet_forgot_password', array('MnetPluginUtils', 'forgotPassword'));

        // Slot configurations
        add_action('wp_ajax_mnet_get_no_of_ad_slots', array('MnetAdHandleAjaxCalls', 'getNoOfAdSlots'));
        add_action('wp_ajax_mnet_remove_all_slot', array('MnetAdHandleAjaxCalls', 'removeAllSlots'));

        // Basic configurations
        add_action('wp_ajax_mnet_get_ad_slots', array('MnetAdBasicConfiguration', 'getAdSlots'));
        add_action('wp_ajax_mnet_save_ad_slots', array('MnetAdBasicConfiguration', 'saveAdSlots'));

        // Advance configurations
        add_action('wp_ajax_mnet_get_ad_data', array('MnetAdAdvanceConfiguration', 'getAdData'));
        add_action('wp_ajax_mnet_save_ad_slot', array('MnetAdAdvanceConfiguration', 'saveAdSlot'));
        add_action('wp_ajax_mnet_remove_ad_slot', array('MnetAdAdvanceConfiguration', 'removeAdSlot'));

        // Ad Tags
        add_action('wp_ajax_mnet_refresh_ad_tags', array('MnetAdHandleAjaxCalls', 'refreshAdtags'));
        add_action('wp_ajax_mnet_get_ad_tags', array('MnetAdHandleAjaxCalls', 'getAdTags'));

        // Dashboard - Reports
        add_action('wp_ajax_mnet_fetch_report', array('MnetReportManager', 'getReport'));
        add_action('wp_ajax_mnet_dashboard_stats', array('MnetReportManager', 'getDashboardStats'));
        add_action('wp_ajax_mnet_dashboard_revenue_details', array('MnetReportManager', 'getDashboardRevenueDetails'));

        // Mail
        add_action('wp_ajax_mnet_send_feedback_mail', array('MnetPluginUtils', 'sendTroubleFeedbackMail'));
        add_action('wp_ajax_mnet_get_max_upload_size', array('MnetAdHandleAjaxCalls', 'getUploadMaxSize'));
        add_action('wp_ajax_mnet_send_mail', array('MnetAdHandleAjaxCalls', 'sendMail'));
        add_action('wp_mail_failed', array('MnetAdManagerPlugin', 'action_wp_mail_failed'), 10, 1);

        // URL blocking
        add_action('wp_ajax_mnet_get_urls', array('MnetAdHandleAjaxCalls', 'getBlockedAndAllUrls'));
        add_action('wp_ajax_mnet_block_urls', array('MnetAdHandleAjaxCalls', 'blockUrls'));

        // FAQs
        add_action('wp_ajax_mnet_get_faqs', array('MnetFaqs', 'index'));
        add_action('wp_ajax_mnet_get_troubleshoot_faqs', array('MnetFaqs', 'getTroubleshootFaqs'));
        
        // Adstxt
        add_action('wp_ajax_mnet_get_adstxt_details', array('MnetAdstxtManager', 'getAdstxtDetails'));

        // Public hooks
        // inject media.net's script in head
        add_action('wp_head', array('MnetAdPublicHooks', 'publicInjectInHead'));

        add_action('loop_start', array('MnetAdPublicHooks', 'publicInjectLoopStart'));
        add_action('loop_end', array('MnetAdPublicHooks', 'publicInjectLoopEnd'));

        add_action('the_post', array('MnetAdPublicHooks', 'publicInjectBetweenPosts'));
        add_action('wp_enqueue_scripts', array('MnetAdPublicHooks', 'enqueueScripts'));
        add_filter('the_content', array('MnetAdPublicHooks', 'mnetPublicInjectInContent'));

        // Sidebar widgets
        add_action('widgets_init', array('MnetAdPublicHooks', 'mnet_widgets_init'));
    }

    public static function action_wp_mail_failed($wp_error)
    {
        return error_log("Mail sending error: " . print_r($wp_error, true));
    }
}
