<?php
ob_start();
require_once __DIR__ . '/../MnetDbManager.php';
require_once __DIR__ . '/MnetLogManager.php';
require_once __DIR__ . '/MnetAuthManager.php';
require_once __DIR__ . '/../utils/MnetAdUtils.php';
require_once __DIR__ . '/MnetPluginUtils.php';
require_once __DIR__ . '/MnetNotices.php';
require_once __DIR__ . '/MnetAdTag.php';
require_once __DIR__ . '/../utils/MnetURLs.php';
require_once __DIR__ . '/../utils/MnetAdSlot.php';

class MnetAdHandleAjaxCalls
{
    public static function getBlockedAndAllUrls()
    {
        MnetAuthManager::returnIfSessionExpired();
        $allUrls = MnetAdUtils::getUrls();
        $blockedUrls = MnetURLs::getAllBlocked();
        wp_send_json(compact('allUrls', 'blockedUrls'), 200);
    }

    public static function blockUrls()
    {
        MnetAuthManager::returnIfSessionExpired();
        $urls = $_POST['urls'];
        $urls = empty($urls) ? array() : $urls;
        wp_send_json(array('result' => MnetURLs::block($urls)), 200);
    }

    public static function getNoOfAdSlots()
    {
        MnetAuthManager::returnIfSessionExpired();
        wp_send_json(array('count' => MnetAdSlot::count()), 200);
    }

    public static function getAdTags()
    {
        MnetAuthManager::returnIfSessionExpired();
        wp_send_json(array('adtags' => MnetAdTag::all()), 200);
    }

    public static function removeAllSlots()
    {
        MnetAuthManager::returnIfSessionExpired();
        $result = intval(MnetDbManager::clearSlots());
        wp_send_json(array('reset' => $result), 200);
    }

    public static function refreshAdtags()
    {
        MnetAuthManager::returnIfSessionExpired();
        try {
            $result = MnetAdTag::fetchAdTags();
            if (isset($result['status']) && $result['status'] == 'error') {
                wp_send_json_error(array("type" => "error", "message" => $result['message']), 500);
            }
            wp_send_json($result, 200);
        } catch (Exception $e) {
            wp_send_json_error(array("type" => "error", "message" => "Failed to refresh Ad tags"), 500);
        }
    }

    public static function getCustomerName()
    {
        MnetAuthManager::returnIfSessionExpired();
        wp_send_json(array('name' => MnetAuthManager::getCustomerName()), 200);
    }

    public static function logout()
    {
        MnetAuthManager::returnIfSessionExpired();
        $keep_slots = intval(json_decode($_GET['keepSlots']));
        if (!$keep_slots) {
            MnetDbManager::clearSlots();
        }
        MnetAuthManager::logout();
        wp_send_json(array('status' => 'logged out'), 200);
    }

    public static function getUploadMaxSize()
    {
        MnetAuthManager::returnIfSessionExpired();
        wp_send_json(array('post_max' => ini_get('post_max_size'), 'upload_file_max' => ini_get('upload_max_filesize')), 200);
    }

    public static function sendMail()
    {
        MnetAuthManager::returnIfSessionExpired();
        $attachments = array();
        if (isset($_FILES['attachments'])) {
            foreach ($_FILES['attachments']['tmp_name'] as $index => $src) {
                $tmpPath = WP_CONTENT_DIR . '/uploads/' . $_FILES['attachments']['name'][$index];
                if (move_uploaded_file($src, $tmpPath)) {
                    $attachments[] = $tmpPath;
                }
            }
        }
        $subject = "[Wordpress-Plugin-Support]: " . $_POST['subject'];
        $content = $_POST['content'];
        $headers = array('Content-Type: text/html; charset=UTF-8');
        $headers[] = "From: " . MnetAuthManager::getCustomerEmail();
        if (MnetAuthManager::getIsCustomerInactive()) {
            $to = 'publisher-appeal@media.net';
            $headers[] = "Cc: wpsupport@media.net";
        } elseif (MnetAuthManager::getSiteStatus() === 'site_rejected_error') {
            $to = 'pubsupport@media.net';
            $headers[] = "Cc: wpsupport@media.net";
        } else {
            $to = 'pubsupport@media.net';
        }
        $message = self::getFormattedMailContent($content);
        $mail_sent = intval(wp_mail($to, $subject, $message, $headers, $attachments));
        if ($mail_sent) {
            wp_send_json("Mail sent successfully!", 200);
        }
        wp_send_json_error("Failed to send mail. Please check your Hosting Settings/MX Record", 500);
    }

    public static function getFormattedMailContent($content)
    {
        $finalContent = "<b>Customer name:</b> " . MnetAuthManager::getCustomerName();
        $finalContent .= "<br><b>Domain name:</b> " . get_home_url();
        $email = MnetPluginUtils::getUserEmailId();
        if ($email) {
            $finalContent .= "<br><b>Customer wordpress email:</b> " . $email;
        }
        return $finalContent . "<br><b>User Message:</b> <br>" . $content;
    }

    public static function getFaqs()
    {
        MnetAuthManager::returnIfSessionExpired();
        $access_token = MnetAuthManager::getAccessToken();
        $url = MNET_API_ENDPOINT . 'faq?access_token=' . $access_token;
        $response = wp_remote_get($url, DefaultOptions::$MNET_API_DEFAULT_ARGS);
        if (is_wp_error($response) || !isset($response['body']) || $response['body'] == "") {
            wp_send_json_error(
                array("status" => "error", "message" => "Failed to fetch FAQs"),
                400
            );
        }
        wp_send_json(json_decode($response['body']));
    }

    public static function getAllNotices()
    {
        wp_send_json(array('notices' => MnetNotices::getAdminNotices()), 200);
    }

    public static function dismissNotice()
    {
        $id = $_POST['id'];
        MnetNotices::dismissNotice($id);
    }

    public static function logAdminPageError($data = null)
    {
        if (empty($data)) {
            $data = $_POST;
        }
        MnetPluginUtils::sendErrorReport($data);
    }
}
