<?php

class MnetModuleManager
{
    public static function getModules()
    {
        $pubConsoleUnblockedModules = MnetModuleManager::getPubConsoleUnblockedModules();

        $siteMapped = MnetAuthManager::getSiteMapped();
        $isAdstxtBlocked = !array_search('adstxt', $pubConsoleUnblockedModules);

        $customerInactive = !!MnetAuthManager::getIsCustomerInactive();

        return ['routes' => array_replace_recursive(
            MnetModuleManager::getBaseConfig(),
            array(
                "basicConfigure" => array("isDisabled" => $customerInactive, "isBlocked" => $customerInactive),
                "dashboard" => array("isDisabled" => $customerInactive, "isBlocked" => $customerInactive),
                "reports" => array("isDisabled" => $customerInactive, "isBlocked" => $customerInactive),
                "adstxt" => array("isDisabled" => !$siteMapped, "isBlocked" => $isAdstxtBlocked || $customerInactive),
                "blocking" => array("isDisabled" => $customerInactive, "isBlocked" => $customerInactive),
                "faq" => array("isDisabled" => $customerInactive, "isBlocked" => $customerInactive),
            )
        ), 'actions' => array(
            'configure-mnet-ad' => array("isBlocked" => $customerInactive),
            'refresh-adtags' => array("isBlocked" => $customerInactive),
            'create-ad-tag' => array("isBlocked" => $customerInactive),
        )];
    }

    private static function getBaseConfig()
    {
        return array(
            "basicConfigure" => array("isDisabled" => true, "isBlocked" => true),
            "dashboard" => array("isDisabled" => true, "isBlocked" => true),
            "reports" => array("isDisabled" => true, "isBlocked" => true),
            "adstxt" => array("isDisabled" => true, "isBlocked" => true),
            "blocking" => array("isDisabled" => true, "isBlocked" => true),
            "faq" => array("isDisabled" => true, "isBlocked" => true),
        );
    }

    private static function getPubConsoleUnblockedModules()
    {
        $access_token = MnetAuthManager::getAccessToken();
        $url = MNET_API_ENDPOINT . 'modules?access_token=' . $access_token;
        $response = wp_remote_get($url, DefaultOptions::$MNET_API_DEFAULT_ARGS);

        if (is_wp_error($response) || !isset($response['body']) || $response['body'] == "") {
            return [];
        }

        return json_decode(Arr::get($response, 'body', "{}"), true) ?: array();
    }
}
