<?php

require_once __DIR__ . '/../admin/MnetPluginUtils.php';
require_once __DIR__ . '/../admin/MnetAuthManager.php';
require_once __DIR__ . '/../MnetDbManager.php';
require_once __DIR__ . '/../../helpers.php';

class MnetInjectedAdTag
{
    public static $TAG_TYPE_INTER = 'inter';
    public static $TAG_TYPE_MOBILE = 'mobile';

    public static $P_TYPE_MOBILE_ADS = 5;
    public static $P_TYPE_INTERSTITIAL_ADS = 6;
    public static $P_TYPE_INTERSTITIAL_MOBILE_ADS = 7;

    public static function getTagDetails($tag_id, $type = null)
    {
        $type = $type ? $type : self::$TAG_TYPE_INTER;
        $response = "";
        $method = $type . 'TagTemplate';
        $adtag = MnetAdTag::getAdtag($tag_id);
        if (!empty($adtag)) {
            if (!empty($adtag['ad_code'])) return $adtag['ad_code'];
            $size['width'] = $adtag['width'];
            $size['height'] = $adtag['height'];
            $cust_id = MnetAuthManager::getCustomerId();
            $response = static::$method($cust_id, $adtag['crid'], $size, $adtag['version_id']);
        }
        return $response;
    }

    public static function interTagTemplate($cid, $crid, $size, $versionId)
    {
        $sizeStr = static::getSizeString($size);
        $sizeStr = "";
        $ad_tag = <<<INTER
          <script type="text/javascript">
          window._mNHandle = window._mNHandle || {};
          window._mNHandle.queue = window._mNHandle.queue || [];
          medianet_versionId = "$versionId";
          (function() {
              var sct = document.createElement("script"),
              winObj = window.top || window,
              sctHl = winObj.document.getElementsByTagName("script")[0];
              sct.type = "text/javascript";
              sct.src = 'https://contextual.media.net/inslmedianet.js?cid=$cid&crid=$crid&size=$sizeStr';
              sct.async = "async";
              sctHl.parentNode.insertBefore(sct, sctHl);
          })();
      </script>
INTER;
        return $ad_tag;
    }

    public static function mobileTagTemplate($cid, $crid, $size, $versionId)
    {
        $width = $size['width'];
        $height = $size['height'];

        $ad_tag = <<<MOBILE
        <script id="mNCC" language="javascript">
            medianet_width = "$width";
            medianet_height = "$height";
            medianet_crid = "$crid";
            medianet_versionId = "$versionId";
        </script>
        <script src="//contextual.media.net/nmedianet.js?cid=$cid"></script>
MOBILE;
        return $ad_tag;
    }

    public static function getHeadScript($ptypes)
    {
        $head_code = MnetDbManager::getAdHeadCodes($ptypes);
        if (!empty($head_code)) return implode("\r\n", $head_code);

        $cust_id = MnetAuthManager::getCustomerId();
        $script = <<<SCRIPT
		<script type="text/javascript">
        window._mNHandle = window._mNHandle || {};
        window._mNHandle.queue = window._mNHandle.queue || [];
        medianet_versionId = 4121199;
    </script>
    <script src="//contextual.media.net/dmedianet.js?cid=$cust_id" async="async"></script>
SCRIPT;
        return $script;
    }

    public static function getSizeString($size)
    {
        $sizeStr = $size["width"] . "x" . $size["height"];
        return $sizeStr;
    }

    public static function createTemplateCall($ad_tag, $css_options, $custom_css)
    {
        $divid = $ad_tag['crid'];
        $crid = $ad_tag['crid'];
        $size = self::getSizeString($ad_tag);
        $get_css = static::createCss($css_options, $custom_css);
        return static::tagTemplate($ad_tag, $divid, $crid, $size, $get_css);
    }

    public static function getExternalCode($custom_css, $css_options, $slot)
    {
        $external_code = MnetDbManager::getExternalCode($slot['id']);
        $external_code = html_entity_decode($external_code[0]['code']);
        $css = static::createCss($css_options, $custom_css);
        $ad_tag = <<<ADTAG
        <div class="mnet_plugin externalcode" style="$css">
            $external_code
        </div>
ADTAG;
        return $ad_tag;
    }

    public static function tagTemplate($adtag, $divid, $crid, $size, $css)
    {
        $sizeArr = explode('x', $size);
        $width = $sizeArr[0] . "px";
        if (MnetPluginUtils::getCurrentThemeName() === 'Twenty Twenty') {
            $css .= 'width:' . $width . ';';
        }

        if (!empty($adtag['ad_code'])) {
            $code = $adtag['ad_code'];
            $ad_code = <<<ADTAG
            <div class="mnet_plugin codeblock" style="$css">
                $code
            </div>
ADTAG;
        } else {
            $ad_code = <<<ADTAG
        <div class="mnet_plugin codeblock" style="$css">
            <div id="$divid">
        <script type="text/javascript">
          try {
              window._mNHandle.queue.push(function () {
                  window._mNDetails.loadTag("$divid", "$size", "$crid");
              });
          } catch (error) {}
        </script>
      </div>
    </div>
ADTAG;
        }

        return $ad_code;
    }

    public static function createCss($css_options, $custom_css)
    {
        $css = '';
        if (!empty($css_options)) {
            $alignment = trim($css_options->alignment);
            $sticky = $css_options->sticky;

            $margin_top = $css_options->margin_top;
            $margin_right = $css_options->margin_right;
            $margin_bottom = $css_options->margin_bottom;
            $margin_left = $css_options->margin_left;

            $padding_top = $css_options->padding_top;
            $padding_right = $css_options->padding_right;
            $padding_bottom = $css_options->padding_bottom;
            $padding_left = $css_options->padding_left;

            if ($alignment === "left") {
                $css .= "float:left;";
            } elseif ($alignment === "right") {
                $css .= "float:right;";
            } else {
                $css .= "text-align:$alignment;margin: 0 auto;";
            }

            if ($sticky == "1") {
                $css .= "position:sticky;top:0;z-index:9999;";
            }

            if (intval($margin_top) !== 0) {
                $css .= "margin-top: $margin_top" . "px;";
            }

            if (intval($margin_right) !== 0) {
                $css .= "margin-right: $margin_right" . "px;";
            }

            if (intval($margin_bottom) !== 0) {
                $css .= "margin-bottom: $margin_bottom" . "px;";
            }

            if (intval($margin_left) !== 0) {
                $css .= "margin-left: $margin_left" . "px;";
            }

            if (intval($padding_top) !== 0) {
                $css .= "padding-top: $padding_top" . "px;";
            }

            if (intval($padding_right) !== 0) {
                $css .= "padding-right: $padding_right" . "px;";
            }

            if (intval($padding_bottom) !== 0) {
                $css .= "padding-bottom: $padding_bottom" . "px;";
            }

            if (intval($padding_left) !== 0) {
                $css .= "padding-left: $padding_left" . "px;";
            }
        }

        if (!empty($custom_css)) {
            $css .= $custom_css;
        }
        return $css;
    }
}
